@@ -36,7 +36,7 @@ from .path import (
     TempFilepath, Filetemp,
     TempDirpath, Dirtemp,
     Cachepath,
-    Sentinal,
+    Sentinel,
     SitePackagesDirpath,
 )
 from .environ import (
@@ -52,9 +52,13 @@ from .copy import (
 from .datetime import (
     Datetime,
 )
+from .headers import (
+    Headers,
+    Environ,
+)
 
 
-__version__ = "0.0.20"
+__version__ = "0.0.24"
 
 
 # get rid of "No handler found" warnings (cribbed from requests)
